/*****************************************************************************
 *
 *   Copyright(C) 2012, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************
 * Software that is described herein is for illustrative purposes only
 * which provides customers with programming information regarding the
 * products. This software is supplied "AS IS" without any warranties.
 * Embedded Artists AB assumes no responsibility or liability for the
 * use of the software, conveys no license or title under any patent,
 * copyright, or mask work right to the product. Embedded Artists AB
 * reserves the right to make changes in the software without
 * notification. Embedded Artists AB also make no representation or
 * warranty that such application will be suitable for the specified
 * use without further testing or modification.
 *****************************************************************************/

/******************************************************************************
 * Includes
 *****************************************************************************/
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#include "lpc_types.h"

#include "bsp.h"
#include "eadebug.h"
#include "gps.h"


/******************************************************************************
 * Forward declarations
 *****************************************************************************/

/******************************************************************************
 * Typedefs and defines
 *****************************************************************************/

/******************************************************************************
 * Global Variables
 *****************************************************************************/

uint8_t g_dbbuf[512];

/******************************************************************************
 * Local Variables
 *****************************************************************************/


/******************************************************************************
 * Local Functions
 *****************************************************************************/

static void powerCycle(void)
{
}

static void displayGpsData(const gpsData const * pData)
{
  //Time
  dbg("\r\n%s\r\n", pData->utcTime);

  //Latitude (in ddmmmmmm format, convert to dd.mmmmmm)
  dbg("Latitude: %d.%06d\r\n", pData->latitude / 1000000,
      pData->latitude % 1000000);

  //Longitude (in ddmmmmmm format, convert to dd.mmmmmm)
  dbg("Longitude: %d.%06d\r\n", pData->longitude / 1000000,
      pData->longitude % 1000000);

  //Number of satellites in view
  dbg("#Satellites: %s\r\n", pData->satellitesUsed);
}


/******************************************************************************
 * Main method
 *****************************************************************************/

int main (void)
{
  bsp_comm_arg_t args;

  bsp_init();

  args.arg1 = 9600;
  args.arg2 = BSP_ARG2_UART_DATABIT_8;
  args.arg3 = BSP_ARG3_UART_STOPBIT_1;
  args.arg4 = BSP_ARG4_UART_PARITY_NONE;

  bsp_rf_init(BSP_COMM_UART, &args);

  powerCycle();

  dbg("GPS App - Waiting for GPS data...\r\n");


  while (1) {
    const gpsData* pData = GPSRetreiveData();
    displayGpsData(pData);
    bsp_delayMs(1000);
  }

  return 1;
}



